@@ -3,35 +3,36 @@
 This module, and specifically L{LandscapeSetupScript}, implements the support
 for the C{landscape-config} script.
 """
-
-from __future__ import print_function
-
-from functools import partial
 import getpass
 import io
 import os
 import pwd
+import shlex
 import sys
 import textwrap
+from functools import partial
+from urllib.parse import urlparse
 
-from landscape.lib.compat import input
-from landscape.lib import base64
-
-from landscape.lib.tag import is_valid_tag
-
-from landscape.client.sysvconfig import SysVConfig, ProcessError
-from landscape.lib.amp import MethodCallError
-from landscape.lib.twisted_util import gather_results
-from landscape.lib.fetch import fetch, FetchError
-from landscape.lib.fs import create_binary_file
-from landscape.lib.bootstrap import BootstrapList, BootstrapDirectory
-from landscape.lib.persist import Persist
-from landscape.client.reactor import LandscapeReactor
-from landscape.client.broker.registration import RegistrationError
-from landscape.client.broker.config import BrokerConfiguration
 from landscape.client.broker.amp import RemoteBrokerConnector
+from landscape.client.broker.config import BrokerConfiguration
 from landscape.client.broker.registration import Identity
+from landscape.client.broker.registration import RegistrationError
 from landscape.client.broker.service import BrokerService
+from landscape.client.reactor import LandscapeReactor
+from landscape.client.serviceconfig import ServiceConfig
+from landscape.client.serviceconfig import ServiceConfigException
+from landscape.lib import base64
+from landscape.lib.amp import MethodCallError
+from landscape.lib.bootstrap import BootstrapDirectory
+from landscape.lib.bootstrap import BootstrapList
+from landscape.lib.compat import input
+from landscape.lib.fetch import fetch
+from landscape.lib.fetch import FetchError
+from landscape.lib.fs import create_binary_file
+from landscape.lib.network import get_fqdn
+from landscape.lib.persist import Persist
+from landscape.lib.tag import is_valid_tag
+from landscape.lib.twisted_util import gather_results
 
 
 EXIT_NOT_REGISTERED = 5
@@ -46,8 +47,8 @@ class ImportOptionError(ConfigurationError):
 
 
 def print_text(text, end="\n", error=False):
-    """Display the given text to the user, using stderr if flagged as an error.
-    """
+    """Display the given text to the user, using stderr
+    if flagged as an error."""
     if error:
         stream = sys.stderr
     else:
@@ -66,7 +67,7 @@ def prompt_yes_no(message, default=True):
     """Prompt for a yes/no question and return the answer as bool."""
     default_msg = "[Y/n]" if default else "[y/N]"
     while True:
-        value = input("{} {}: ".format(message, default_msg)).lower()
+        value = input(f"{message} {default_msg}: ").lower()
         if value:
             if value.startswith("n"):
                 return False
@@ -87,7 +88,8 @@ def get_invalid_users(users):
         if "ALL" in user_list:
             if len(user_list) > 1:
                 raise ConfigurationError(
-                    "Extra users specified with ALL users")
+                    "Extra users specified with ALL users",
+                )
             user_list.remove("ALL")
         invalid_users = []
         for user in user_list:
@@ -100,8 +102,15 @@ def get_invalid_users(users):
 
 class LandscapeSetupConfiguration(BrokerConfiguration):
 
-    unsaved_options = ("no_start", "disable", "silent", "ok_no_register",
-                       "import_from")
+    unsaved_options = (
+        "no_start",
+        "disable",
+        "silent",
+        "ok_no_register",
+        "import_from",
+    )
+
+    encoding = "utf-8"
 
     def _load_external_options(self):
         """Handle the --import parameter.
@@ -123,18 +132,23 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
                     content = self.fetch_import_url(self.import_from)
                     parser = self._get_config_object(
                         alternative_config=io.StringIO(
-                            content.decode("utf-8")))
+                            content.decode("utf-8"),
+                        ),
+                    )
                 elif not os.path.isfile(self.import_from):
-                    raise ImportOptionError("File %s doesn't exist." %
-                                            self.import_from)
+                    raise ImportOptionError(
+                        f"File {self.import_from} doesn't exist.",
+                    )
                 else:
                     try:
                         parser = self._get_config_object(
-                            alternative_config=self.import_from)
+                            alternative_config=self.import_from,
+                        )
                     except Exception:
                         raise ImportOptionError(
-                            "Couldn't read configuration from %s." %
-                            self.import_from)
+                            "Couldn't read configuration "
+                            f"from {self.import_from}.",
+                        )
             except Exception as error:
                 raise ImportOptionError(str(error))
 
@@ -143,15 +157,16 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
             if parser and self.config_section in parser:
                 options = parser[self.config_section]
             if not options:
-                raise ImportOptionError("Nothing to import at %s." %
-                                        self.import_from)
+                raise ImportOptionError(
+                    f"Nothing to import at {self.import_from}.",
+                )
             options.update(self._command_line_options)
             self._command_line_options = options
 
     def fetch_import_url(self, url):
         """Handle fetching of URLs passed to --url."""
 
-        print_text("Fetching configuration from %s..." % url)
+        print_text(f"Fetching configuration from {url}...")
         error_message = None
         try:
             content = fetch(url)
@@ -159,52 +174,79 @@ class LandscapeSetupConfiguration(BrokerConfiguration):
             error_message = str(error)
         if error_message is not None:
             raise ImportOptionError(
-                "Couldn't download configuration from %s: %s" %
-                (url, error_message))
+                f"Couldn't download configuration from {url}: {error_message}",
+            )
         return content
 
     def make_parser(self):
         """
         Specialize the parser, adding configure-specific options.
         """
-        parser = super(LandscapeSetupConfiguration, self).make_parser()
+        parser = super().make_parser()
 
-        parser.add_option("--import", dest="import_from",
-                          metavar="FILENAME_OR_URL",
-                          help="Filename or URL to import configuration from. "
-                               "Imported options behave as if they were "
-                               "passed in the command line, with precedence "
-                               "being given to real command line options.")
-        parser.add_option("--script-users", metavar="USERS",
-                          help="A comma-separated list of users to allow "
-                               "scripts to run.  To allow scripts to be run "
-                               "by any user, enter: ALL")
-        parser.add_option("--include-manager-plugins", metavar="PLUGINS",
-                          default="",
-                          help="A comma-separated list of manager plugins to "
-                               "load.")
-        parser.add_option("-n", "--no-start", action="store_true",
-                          help="Don't start the client automatically.")
-        parser.add_option("--ok-no-register", action="store_true",
-                          help="Return exit code 0 instead of 2 if the client "
-                          "can't be registered.")
-        parser.add_option("--silent", action="store_true", default=False,
-                          help="Run without manual interaction.")
-        parser.add_option("--disable", action="store_true", default=False,
-                          help="Stop running clients and disable start at "
-                               "boot.")
-        parser.add_option("--init", action="store_true", default=False,
-                          help="Set up the client directories structure "
-                               "and exit.")
-        parser.add_option("--is-registered", action="store_true",
-                          help="Exit with code 0 (success) if client is "
-                               "registered else returns {}. Displays "
-                               "registration info."
-                               .format(EXIT_NOT_REGISTERED))
+        parser.add_option(
+            "--import",
+            dest="import_from",
+            metavar="FILENAME_OR_URL",
+            help="Filename or URL to import configuration from. "
+            "Imported options behave as if they were "
+            "passed in the command line, with precedence "
+            "being given to real command line options.",
+        )
+        parser.add_option(
+            "--script-users",
+            metavar="USERS",
+            help="A comma-separated list of users to allow "
+            "scripts to run.  To allow scripts to be run "
+            "by any user, enter: ALL",
+        )
+        parser.add_option(
+            "--include-manager-plugins",
+            metavar="PLUGINS",
+            default="",
+            help="A comma-separated list of manager plugins to " "load.",
+        )
+        parser.add_option(
+            "-n",
+            "--no-start",
+            action="store_true",
+            help="Don't start the client automatically.",
+        )
+        parser.add_option(
+            "--ok-no-register",
+            action="store_true",
+            help="Return exit code 0 instead of 2 if the client "
+            "can't be registered.",
+        )
+        parser.add_option(
+            "--silent",
+            action="store_true",
+            default=False,
+            help="Run without manual interaction.",
+        )
+        parser.add_option(
+            "--disable",
+            action="store_true",
+            default=False,
+            help="Stop running clients and disable start at " "boot.",
+        )
+        parser.add_option(
+            "--init",
+            action="store_true",
+            default=False,
+            help="Set up the client directories structure " "and exit.",
+        )
+        parser.add_option(
+            "--is-registered",
+            action="store_true",
+            help="Exit with code 0 (success) if client is "
+            "registered else returns {}. Displays "
+            "registration info.".format(EXIT_NOT_REGISTERED),
+        )
         return parser
 
 
-class LandscapeSetupScript(object):
+class LandscapeSetupScript:
     """
     An interactive procedure which manages the prompting and temporary storage
     of configuration parameters.
@@ -218,6 +260,16 @@ class LandscapeSetupScript(object):
 
     def __init__(self, config):
         self.config = config
+        self.landscape_domain = None
+
+    def get_domain(self):
+        domain = self.landscape_domain
+        if domain:
+            return domain
+        url = self.config.url
+        if url:
+            return urlparse(url).netloc
+        return "landscape.canonical.com"
 
     def prompt_get_input(self, msg, required):
         """Prompt the user on the terminal for a value
@@ -226,14 +278,14 @@ class LandscapeSetupScript(object):
         @param required: True if value must be entered
         """
         while True:
-            value = input(msg)
+            value = input(msg).strip()
             if value:
                 return value
             elif not required:
                 break
             show_help("This option is required to configure Landscape.")
 
-    def prompt(self, option, msg, required=False):
+    def prompt(self, option, msg, required=False, default=None):
         """Prompt the user on the terminal for a value.
 
         @param option: The attribute of C{self.config} that contains the
@@ -241,16 +293,21 @@ class LandscapeSetupScript(object):
         @param msg: The message to prompt the user with (via C{input}).
         @param required: If True, the user will be required to enter a value
             before continuing.
+        @param default: Default only if set and no current value present
         """
-        default = getattr(self.config, option, None)
+        cur_value = getattr(self.config, option, None)
+        if cur_value:
+            default = cur_value
         if default:
-            msg += " [%s]: " % default
+            msg += f" [{default}]: "
         else:
             msg += ": "
         required = required and not (bool(default))
         result = self.prompt_get_input(msg, required)
         if result:
             setattr(self.config, option, result)
+        elif default:
+            setattr(self.config, option, default)
 
     def password_prompt(self, option, msg, required=False):
         """Prompt the user on the terminal for a password and mask the value.
@@ -287,25 +344,31 @@ class LandscapeSetupScript(object):
         show_help(
             """
             The computer title you provide will be used to represent this
-            computer in the Landscape user interface. It's important to use
-            a title that will allow the system to be easily recognized when
-            it appears on the pending computers page.
-            """)
-
-        self.prompt("computer_title", "This computer's title", True)
+            computer in the Landscape dashboard.
+            """,
+        )
+        self.prompt(
+            "computer_title",
+            "This computer's title",
+            False,
+            default=get_fqdn(),
+        )
 
     def query_account_name(self):
         if "account_name" in self.config.get_command_line_options():
             return
 
-        show_help(
-            """
-            You must now specify the name of the Landscape account you
-            want to register this computer with. Your account name is shown
-            under 'Account name' at https://landscape.canonical.com .
-            """)
-
-        self.prompt("account_name", "Account name", True)
+        if not self.landscape_domain:
+            show_help(
+                """
+                You must now specify the name of the Landscape account you
+                want to register this computer with. Your account name is shown
+                under 'Account name' at https://landscape.canonical.com .
+                """,
+            )
+            self.prompt("account_name", "Account name", True)
+        else:
+            self.config.account_name = "standalone"
 
     def query_registration_key(self):
         command_line_options = self.config.get_command_line_options()
@@ -313,18 +376,15 @@ class LandscapeSetupScript(object):
             return
 
         show_help(
-            """
-            A registration key may be associated with your Landscape
-            account to prevent unauthorized registration attempts.  This
-            is not your personal login password.  It is optional, and unless
-            explicitly set on the server, it may be skipped here.
+            f"""
+            A Registration Key prevents unauthorized registration attempts.
 
-            If you don't remember the registration key you can find it
-            at https://landscape.canonical.com/account/%s
-            """ % self.config.account_name)
+            Provide the Registration Key found at:
+            https://{self.get_domain()}/account/{self.config.account_name}
+            """,  # noqa: E501
+        )
 
-        self.password_prompt("registration_key",
-                             "Account registration key")
+        self.password_prompt("registration_key", "(Optional) Registration Key")
 
     def query_proxies(self):
         options = self.config.get_command_line_options()
@@ -333,11 +393,10 @@ class LandscapeSetupScript(object):
 
         show_help(
             """
-            The Landscape client communicates with the server over HTTP and
-            HTTPS.  If your network requires you to use a proxy to access HTTP
-            and/or HTTPS web sites, please provide the address of these
-            proxies now.  If you don't use a proxy, leave these fields empty.
-            """)
+            If your network requires you to use a proxy, provide the address of
+            these proxies now.
+            """,
+        )
 
         if "http_proxy" not in options:
             self.prompt("http_proxy", "HTTP proxy URL")
@@ -349,47 +408,12 @@ class LandscapeSetupScript(object):
         if "include_manager_plugins" in options and "script_users" in options:
             invalid_users = get_invalid_users(options["script_users"])
             if invalid_users:
-                raise ConfigurationError("Unknown system users: %s" %
-                                         ", ".join(invalid_users))
+                raise ConfigurationError(
+                    "Unknown system users: {}".format(
+                        ", ".join(invalid_users),
+                    ),
+                )
             return
-        show_help(
-            """
-            Landscape has a feature which enables administrators to run
-            arbitrary scripts on machines under their control. By default this
-            feature is disabled in the client, disallowing any arbitrary script
-            execution. If enabled, the set of users that scripts may run as is
-            also configurable.
-            """)
-        msg = "Enable script execution?"
-        included_plugins = [
-            p.strip() for p in self.config.include_manager_plugins.split(",")]
-        if included_plugins == [""]:
-            included_plugins = []
-        default = "ScriptExecution" in included_plugins
-        if prompt_yes_no(msg, default=default):
-            if "ScriptExecution" not in included_plugins:
-                included_plugins.append("ScriptExecution")
-            show_help(
-                """
-                By default, scripts are restricted to the 'landscape' and
-                'nobody' users. Please enter a comma-delimited list of users
-                that scripts will be restricted to. To allow scripts to be run
-                by any user, enter "ALL".
-                """)
-            while True:
-                self.prompt("script_users", "Script users")
-                invalid_users = get_invalid_users(
-                    self.config.script_users)
-                if not invalid_users:
-                    break
-                else:
-                    show_help("Unknown system users: {}".format(
-                        ",".join(invalid_users)))
-                    self.config.script_users = None
-        else:
-            if "ScriptExecution" in included_plugins:
-                included_plugins.remove("ScriptExecution")
-        self.config.include_manager_plugins = ", ".join(included_plugins)
 
     def query_access_group(self):
         """Query access group from the user."""
@@ -399,7 +423,8 @@ class LandscapeSetupScript(object):
 
         show_help(
             "You may provide an access group for this computer "
-            "e.g. webservers.")
+            "e.g. webservers.",
+        )
         self.prompt("access_group", "Access group", False)
 
     def _get_invalid_tags(self, tagnames):
@@ -419,53 +444,97 @@ class LandscapeSetupScript(object):
         if "tags" in options:
             invalid_tags = self._get_invalid_tags(options["tags"])
             if invalid_tags:
-                raise ConfigurationError("Invalid tags: %s" %
-                                         ", ".join(invalid_tags))
+                raise ConfigurationError(
+                    "Invalid tags: {}".format(", ".join(invalid_tags)),
+                )
             return
 
+    def query_landscape_edition(self):
         show_help(
-            "You may provide tags for this computer e.g. server,precise.")
-        while True:
-            self.prompt("tags", "Tags", False)
-            if self._get_invalid_tags(self.config.tags):
-                show_help(
-                    "Tag names may only contain alphanumeric characters.")
-                self.config.tags = None  # Reset for the next prompt
-            else:
-                break
+            "Manage this machine with Landscape "
+            "(https://ubuntu.com/landscape):\n",
+        )
+        options = self.config.get_command_line_options()
+        if "ping_url" in options and "url" in options:
+            return
+        if prompt_yes_no(
+            "Will you be using your own Self-Hosted Landscape installation?",
+            default=False,
+        ):
+            show_help(
+                "Provide the fully qualified domain name "
+                "of your Landscape Server e.g. "
+                "landscape.yourdomain.com",
+            )
+            self.landscape_domain = self.prompt_get_input(
+                "Landscape Domain: ",
+                True,
+            )
+            self.config.ping_url = f"http://{self.landscape_domain}/ping"
+            self.config.url = f"https://{self.landscape_domain}/message-system"
+        else:
+            self.landscape_domain = ""
+            self.config.ping_url = self.config._command_line_defaults[
+                "ping_url"
+            ]
+            self.config.url = self.config._command_line_defaults["url"]
+            if self.config.account_name == "standalone":
+                self.config.account_name = ""
 
-    def show_header(self):
-        show_help(
+    def show_summary(self):
+
+        tx = f"""A summary of the provided information:
+            Computer's Title: {self.config.computer_title}
+            Account Name: {self.config.account_name}
+            Landscape FQDN: {self.get_domain()}
+            Registration Key: {True if self.config.registration_key else False}
             """
-            This script will interactively set up the Landscape client. It will
-            ask you a few questions about this computer and your Landscape
-            account, and will submit that information to the Landscape server.
-            After this computer is registered it will need to be approved by an
-            account administrator on the pending computers page.
+        show_help(tx)
+        if self.config.http_proxy or self.config.https_proxy:
+            show_help(
+                f"""HTTPS Proxy: {self.config.https_proxy}
+                    HTTP  Proxy: {self.config.http_proxy}""",
+            )
 
-            Please see https://landscape.canonical.com for more information.
-            """)
+        params = (
+            "account_name",
+            "url",
+            "ping_url",
+            "registration_key",
+            "https_proxy",
+            "http_proxy",
+        )
+        cmd = ["sudo", "landscape-config"]
+        for param in params:
+            value = self.config.get(param)
+            if value:
+                if param in self.config._command_line_defaults:
+                    if value == self.config._command_line_defaults[param]:
+                        continue
+                cmd.append("--" + param.replace("_", "-"))
+                if param == "registration_key":
+                    cmd.append("HIDDEN")
+                else:
+                    cmd.append(shlex.quote(value))
+        show_help(
+            "The landscape-config parameters to repeat this registration"
+            " on another machine are:",
+        )
+        show_help(" ".join(cmd))
 
     def run(self):
         """Kick off the interactive process which prompts the user for data.
 
         Data will be saved to C{self.config}.
         """
-        self.show_header()
+        self.query_landscape_edition()
         self.query_computer_title()
         self.query_account_name()
         self.query_registration_key()
         self.query_proxies()
         self.query_script_plugin()
-        self.query_access_group()
         self.query_tags()
-
-
-def setup_init_script_and_start_client():
-    "Configure the init script to start the client on boot."
-    # XXX This function is misnamed; it doesn't start the client.
-    sysvconfig = SysVConfig()
-    sysvconfig.set_start_on_boot(True)
+        self.show_summary()
 
 
 def stop_client_and_disable_init_script():
@@ -473,9 +542,8 @@ def stop_client_and_disable_init_script():
     Stop landscape-client and change configuration to prevent starting
     landscape-client on boot.
     """
-    sysvconfig = SysVConfig()
-    sysvconfig.stop_landscape()
-    sysvconfig.set_start_on_boot(False)
+    ServiceConfig.stop_landscape()
+    ServiceConfig.set_start_on_boot(False)
 
 
 def setup_http_proxy(config):
@@ -496,8 +564,9 @@ def check_account_name_and_password(config):
     """
     if config.silent and not config.no_start:
         if not (config.get("account_name") and config.get("computer_title")):
-            raise ConfigurationError("An account name and computer title are "
-                                     "required.")
+            raise ConfigurationError(
+                "An account name and computer title are " "required.",
+            )
 
 
 def check_script_users(config):
@@ -508,8 +577,9 @@ def check_script_users(config):
     if config.get("script_users"):
         invalid_users = get_invalid_users(config.get("script_users"))
         if invalid_users:
-            raise ConfigurationError("Unknown system users: %s" %
-                                     ", ".join(invalid_users))
+            raise ConfigurationError(
+                "Unknown system users: {}".format(", ".join(invalid_users)),
+            )
         if not config.include_manager_plugins:
             config.include_manager_plugins = "ScriptExecution"
 
@@ -523,9 +593,9 @@ def decode_base64_ssl_public_certificate(config):
     # certificate, but the actual certificate itself.
     if config.ssl_public_key and config.ssl_public_key.startswith("base64:"):
         decoded_cert = base64.decodebytes(
-            config.ssl_public_key[7:].encode("ascii"))
-        config.ssl_public_key = store_public_key_data(
-            config, decoded_cert)
+            config.ssl_public_key[7:].encode("ascii"),
+        )
+        config.ssl_public_key = store_public_key_data(config, decoded_cert)
 
 
 def setup(config):
@@ -538,19 +608,11 @@ def setup(config):
     """
     bootstrap_tree(config)
 
-    sysvconfig = SysVConfig()
     if not config.no_start:
         if config.silent:
-            setup_init_script_and_start_client()
-        elif not sysvconfig.is_configured_to_run():
-            answer = prompt_yes_no(
-                "\nThe Landscape client must be started "
-                "on boot to operate correctly.\n\n"
-                "Start Landscape client on boot?")
-            if answer:
-                setup_init_script_and_start_client()
-            else:
-                sys.exit("Aborting Landscape configuration")
+            ServiceConfig.set_start_on_boot(True)
+        elif not ServiceConfig.is_configured_to_run():
+            ServiceConfig.set_start_on_boot(True)
 
     setup_http_proxy(config)
     check_account_name_and_password(config)
@@ -564,11 +626,14 @@ def setup(config):
     # Restart the client to ensure that it's using the new configuration.
     if not config.no_start:
         try:
-            sysvconfig.restart_landscape()
-        except ProcessError:
-            print_text("Couldn't restart the Landscape client.", error=True)
-            print_text("This machine will be registered with the provided "
-                       "details when the client runs.", error=True)
+            ServiceConfig.restart_landscape()
+        except ServiceConfigException as exc:
+            print_text(str(exc), error=True)
+            print_text(
+                "This machine will be registered with the provided "
+                "details when the client runs.",
+                error=True,
+            )
             exit_code = 2
             if config.ok_no_register:
                 exit_code = 0
@@ -579,10 +644,17 @@ def bootstrap_tree(config):
     """Create the client directories tree."""
     bootstrap_list = [
         BootstrapDirectory("$data_path", "landscape", "root", 0o755),
-        BootstrapDirectory("$annotations_path", "landscape", "landscape",
-                           0o755)]
+        BootstrapDirectory(
+            "$annotations_path",
+            "landscape",
+            "landscape",
+            0o755,
+        ),
+    ]
     BootstrapList(bootstrap_list).bootstrap(
-        data_path=config.data_path, annotations_path=config.annotations_path)
+        data_path=config.data_path,
+        annotations_path=config.annotations_path,
+    )
 
 
 def store_public_key_data(config, certificate_data):
@@ -598,8 +670,9 @@ def store_public_key_data(config, certificate_data):
     """
     key_filename = os.path.join(
         config.data_path,
-        os.path.basename(config.get_config_filename() + ".ssl_public_key"))
-    print_text("Writing SSL CA certificate to %s..." % key_filename)
+        os.path.basename(config.get_config_filename() + ".ssl_public_key"),
+    )
+    print_text(f"Writing SSL CA certificate to {key_filename}...")
     create_binary_file(key_filename, certificate_data)
     return key_filename
 
@@ -647,13 +720,18 @@ def done(ignored_result, connector, reactor):
 
 def got_connection(add_result, connector, reactor, remote):
     """Handle becomming connected to a broker."""
-    handlers = {"registration-done": partial(success, add_result),
-                "registration-failed": partial(failure, add_result),
-                "exchange-failed": partial(exchange_failure, add_result)}
+    handlers = {
+        "registration-done": partial(success, add_result),
+        "registration-failed": partial(failure, add_result),
+        "exchange-failed": partial(exchange_failure, add_result),
+    }
     deferreds = [
         remote.call_on_event(handlers),
         remote.register().addErrback(
-            partial(handle_registration_errors, add_result), connector)]
+            partial(handle_registration_errors, add_result),
+            connector,
+        ),
+    ]
     results = gather_results(deferreds)
     results.addCallback(done, connector, reactor)
     return results
@@ -667,9 +745,15 @@ def got_error(failure, reactor, add_result, print=print):
     reactor.stop()
 
 
-def register(config, reactor=None, connector_factory=RemoteBrokerConnector,
-             got_connection=got_connection, max_retries=14, on_error=None,
-             results=None):
+def register(
+    config,
+    reactor=None,
+    connector_factory=RemoteBrokerConnector,
+    got_connection=got_connection,
+    max_retries=14,
+    on_error=None,
+    results=None,
+):
     """Instruct the Landscape Broker to register the client.
 
     The broker will be instructed to reload its configuration and then to
@@ -701,9 +785,11 @@ def register(config, reactor=None, connector_factory=RemoteBrokerConnector,
     connector = connector_factory(reactor, config)
     connection = connector.connect(max_retries=max_retries, quiet=True)
     connection.addCallback(
-        partial(got_connection, add_result, connector, reactor))
+        partial(got_connection, add_result, connector, reactor),
+    )
     connection.addErrback(
-        partial(got_error, reactor=reactor, add_result=add_result))
+        partial(got_error, reactor=reactor, add_result=add_result),
+    )
     reactor.run()
 
     assert len(results) == 1, "We expect exactly one result."
@@ -721,27 +807,30 @@ def register(config, reactor=None, connector_factory=RemoteBrokerConnector,
 
 
 def report_registration_outcome(what_happened, print=print):
-    """Report the registration interaction outcome to the user in human-readable
-    form.
+    """Report the registration interaction outcome to the user in
+    human-readable form.
     """
     messages = {
-        "success": "System successfully registered.",
+        "success": "Registration request sent successfully.",
         "unknown-account": "Invalid account name or registration key.",
         "max-pending-computers": (
             "Maximum number of computers pending approval reached. ",
             "Login to your Landscape server account page to manage "
-            "pending computer approvals."),
+            "pending computer approvals.",
+        ),
         "ssl-error": (
             "\nThe server's SSL information is incorrect, or fails "
             "signature verification!\n"
             "If the server is using a self-signed certificate, "
             "please ensure you supply it with the --ssl-public-key "
-            "parameter."),
+            "parameter."
+        ),
         "non-ssl-error": (
             "\nWe were unable to contact the server.\n"
             "Your internet connection may be down. "
             "The landscape client will continue to try and contact "
-            "the server periodically.")
+            "the server periodically."
+        ),
     }
     message = messages.get(what_happened)
     if message:
@@ -762,28 +851,34 @@ def determine_exit_code(what_happened):
 def is_registered(config):
     """Return whether the client is already registered."""
     persist_filename = os.path.join(
-        config.data_path, "{}.bpickle".format(BrokerService.service_name))
+        config.data_path,
+        f"{BrokerService.service_name}.bpickle",
+    )
     persist = Persist(filename=persist_filename)
     identity = Identity(config, persist)
     return bool(identity.secure_id)
 
 
 def registration_info_text(config, registration_status):
-    '''
+    """
     A simple output displaying whether the client is registered or not, the
     account name, and config and data paths
-    '''
+    """
 
     config_path = os.path.abspath(config._config_filename)
 
-    text = textwrap.dedent("""
+    text = textwrap.dedent(
+        """
                            Registered:    {}
                            Config Path:   {}
-                           Data Path      {}"""
-                           .format(registration_status, config_path,
-                                   config.data_path))
+                           Data Path      {}""".format(
+            registration_status,
+            config_path,
+            config.data_path,
+        ),
+    )
     if registration_status:
-        text += '\nAccount Name:  {}'.format(config.account_name)
+        text += f"\nAccount Name:  {config.account_name}"
 
     return text
 
@@ -829,8 +924,6 @@ def main(args, print=print):
         print_text(str(e))
         sys.exit("Aborting Landscape configuration")
 
-    print("Please wait...")
-
     # Attempt to register the client.
     reactor = LandscapeReactor()
     if config.silent:
@@ -841,7 +934,8 @@ def main(args, print=print):
         default_answer = not is_registered(config)
         answer = prompt_yes_no(
             "\nRequest a new registration for this computer now?",
-            default=default_answer)
+            default=default_answer,
+        )
         if answer:
             result = register(config, reactor)
             report_registration_outcome(result, print=print)
