@@ -4,9 +4,16 @@ from landscape.client.deployment import Configuration
 from landscape.client.manager.scriptexecution import ALL_USERS
 
 
-ALL_PLUGINS = ["ProcessKiller", "PackageManager", "UserManager",
-               "ShutdownManager", "AptSources", "HardwareInfo",
-               "KeystoneToken"]
+ALL_PLUGINS = [
+    "ProcessKiller",
+    "PackageManager",
+    "UserManager",
+    "ShutdownManager",
+    "AptSources",
+    "HardwareInfo",
+    "KeystoneToken",
+    "SnapManager",
+]
 
 
 class ManagerConfiguration(Configuration):
@@ -17,26 +24,38 @@ class ManagerConfiguration(Configuration):
         Specialize L{Configuration.make_parser}, adding many
         manager-specific options.
         """
-        parser = super(ManagerConfiguration, self).make_parser()
+        parser = super().make_parser()
 
-        parser.add_option("--manager-plugins", metavar="PLUGIN_LIST",
-                          help="Comma-delimited list of manager plugins to "
-                               "use. ALL means use all plugins.",
-                          default="ALL")
-        parser.add_option("--include-manager-plugins", metavar="PLUGIN_LIST",
-                          help="Comma-delimited list of manager plugins to "
-                               "enable, in addition to the defaults.")
-        parser.add_option("--script-users", metavar="USERS",
-                          help="Comma-delimited list of usernames that scripts"
-                               " may be run as. Default is to allow all "
-                               "users.")
-        parser.add_option("--script-output-limit",
-                          metavar="SCRIPT_OUTPUT_LIMIT",
-                          type="int", default=512,
-                          help="Maximum allowed output size that scripts"
-                               " can send. "
-                               "Script output will be truncated at that limit."
-                               " Default is 512 (kB)")
+        parser.add_option(
+            "--manager-plugins",
+            metavar="PLUGIN_LIST",
+            help="Comma-delimited list of manager plugins to "
+            "use. ALL means use all plugins.",
+            default="ALL",
+        )
+        parser.add_option(
+            "--include-manager-plugins",
+            metavar="PLUGIN_LIST",
+            help="Comma-delimited list of manager plugins to "
+            "enable, in addition to the defaults.",
+        )
+        parser.add_option(
+            "--script-users",
+            metavar="USERS",
+            help="Comma-delimited list of usernames that scripts"
+            " may be run as. Default is to allow all "
+            "users.",
+        )
+        parser.add_option(
+            "--script-output-limit",
+            metavar="SCRIPT_OUTPUT_LIMIT",
+            type="int",
+            default=512,
+            help="Maximum allowed output size that scripts"
+            " can send. "
+            "Script output will be truncated at that limit."
+            " Default is 512 (kB)",
+        )
 
         return parser
 
