@@ -2,8 +2,8 @@ import os
 
 from twisted.internet.utils import getProcessOutput
 
-from landscape.lib.encoding import encode_values
 from landscape.client.manager.plugin import ManagerPlugin
+from landscape.lib.encoding import encode_values
 
 
 class HardwareInfo(ManagerPlugin):
@@ -15,17 +15,23 @@ class HardwareInfo(ManagerPlugin):
     command = "/usr/bin/lshw"
 
     def register(self, registry):
-        super(HardwareInfo, self).register(registry)
+        super().register(registry)
         self.call_on_accepted(self.message_type, self.send_message)
 
     def run(self):
         return self.registry.broker.call_if_accepted(
-            self.message_type, self.send_message)
+            self.message_type,
+            self.send_message,
+        )
 
     def send_message(self):
         environ = encode_values(os.environ)
         result = getProcessOutput(
-            self.command, args=["-xml", "-quiet"], env=environ, path=None)
+            self.command,
+            args=["-xml", "-quiet"],
+            env=environ,
+            path=None,
+        )
         return result.addCallback(self._got_output)
 
     def _got_output(self, output):
