@@ -1,10 +1,12 @@
 import logging
 
 from twisted.internet.defer import Deferred
-from twisted.internet.protocol import ProcessProtocol
 from twisted.internet.error import ProcessDone
+from twisted.internet.protocol import ProcessProtocol
 
-from landscape.client.manager.plugin import ManagerPlugin, SUCCEEDED, FAILED
+from landscape.client.manager.plugin import FAILED
+from landscape.client.manager.plugin import ManagerPlugin
+from landscape.client.manager.plugin import SUCCEEDED
 
 
 class ShutdownFailedError(Exception):
@@ -18,7 +20,6 @@ class ShutdownFailedError(Exception):
 
 
 class ShutdownManager(ManagerPlugin):
-
     def __init__(self, process_factory=None):
         if process_factory is None:
             from twisted.internet import reactor as process_factory
@@ -30,7 +31,7 @@ class ShutdownManager(ManagerPlugin):
         The shutdown manager handles C{shutdown} activity messages broadcast
         from the server.
         """
-        super(ShutdownManager, self).register(registry)
+        super().register(registry)
         registry.register_message("shutdown", self.perform_shutdown)
 
     def perform_shutdown(self, message):
@@ -54,22 +55,24 @@ class ShutdownManager(ManagerPlugin):
         deferred = self._respond(SUCCEEDED, data, operation_id)
         # After sending the result to the server, stop accepting messages and
         # wait for the reboot/shutdown.
-        deferred.addCallback(
-            lambda _: self.registry.broker.stop_exchanger())
+        deferred.addCallback(lambda _: self.registry.broker.stop_exchanger())
         return deferred
 
     def _respond_failure(self, failure, operation_id, reboot):
         logging.info("Shutdown request failed.")
-        failure_report = '\n'.join([
-            failure.value.data,
-            "",
-            "Attempting to force {operation}. Please note that if this "
-            "succeeds, Landscape will have no way of knowing and will still "
-            "mark this activity as having failed. It is recommended you check "
-            "the state of the machine manually to determine whether "
-            "{operation} succeeded.".format(
-                operation="reboot" if reboot else "shutdown")
-        ])
+        failure_report = "\n".join(
+            [
+                failure.value.data,
+                "",
+                "Attempting to force {operation}. Please note that if this "
+                "succeeds, Landscape will have no way of knowing and will "
+                "still mark this activity as having failed. It is recommended "
+                "you check the state of the machine manually to determine "
+                "whether {operation} succeeded.".format(
+                    operation="reboot" if reboot else "shutdown",
+                ),
+            ],
+        )
         deferred = self._respond(FAILED, failure_report, operation_id)
         # Add another callback spawning the poweroff or reboot command (which
         # seem more reliable in aberrant situations like a post-trusty release
@@ -81,30 +84,45 @@ class ShutdownManager(ManagerPlugin):
         command, args = self._get_command_and_args(protocol, reboot, True)
         deferred.addCallback(
             lambda _: self._process_factory.spawnProcess(
-                protocol, command, args=args))
+                protocol,
+                command,
+                args=args,
+            ),
+        )
         return deferred
 
     def _respond(self, status, data, operation_id):
-        message = {"type": "operation-result",
-                   "status": status,
-                   "result-text": data,
-                   "operation-id": operation_id}
+        message = {
+            "type": "operation-result",
+            "status": status,
+            "result-text": data,
+            "operation-id": operation_id,
+        }
         return self.registry.broker.send_message(
-            message, self._session_id, True)
+            message,
+            self._session_id,
+            True,
+        )
 
     def _get_command_and_args(self, protocol, reboot, force=False):
         """
         Returns a C{command, args} 2-tuple suitable for use with
         L{IReactorProcess.spawnProcess}.
         """
-        minutes = None if force else "+%d" % (protocol.delay // 60,)
+        minutes = None if force else f"+{protocol.delay//60:d}"
         args = {
             (False, False): [
-                "/sbin/shutdown", "-h", minutes,
-                "Landscape is shutting down the system"],
+                "/sbin/shutdown",
+                "-h",
+                minutes,
+                "Landscape is shutting down the system",
+            ],
             (False, True): [
-                "/sbin/shutdown", "-r", minutes,
-                "Landscape is rebooting the system"],
+                "/sbin/shutdown",
+                "-r",
+                minutes,
+                "Landscape is rebooting the system",
+            ],
             (True, False): ["/sbin/poweroff"],
             (True, True): ["/sbin/reboot"],
         }[force, reboot]
@@ -148,7 +166,7 @@ class ShutdownProcessProtocol(ProcessProtocol):
         """
         reactor.call_later(timeout, self._succeed)
 
-    def childDataReceived(self, fd, data):
+    def childDataReceived(self, fd, data):  # noqa: N802
         """Some data was received from the child.
 
         Add it to our buffer to pass to C{result} when it's fired.
@@ -156,7 +174,7 @@ class ShutdownProcessProtocol(ProcessProtocol):
         if self._waiting:
             self._data.append(data)
 
-    def processEnded(self, reason):
+    def processEnded(self, reason):  # noqa: N802
         """Fire back the C{result} L{Deferred}.
 
         C{result}'s callback will be fired with the string of data received
