@@ -1,15 +1,17 @@
 import os
+from unittest.mock import ANY
+from unittest.mock import Mock
 
-from mock import Mock, ANY
 from twisted.internet.defer import fail
 
-from landscape.client.amp import ComponentPublisher
-from landscape.client.monitor.usermonitor import (
-    UserMonitor, RemoteUserMonitorConnector)
-from landscape.client.manager.usermanager import UserManager
-from landscape.client.user.tests.helpers import FakeUserProvider
-from landscape.client.tests.helpers import LandscapeTest, MonitorHelper
 import landscape.client.monitor.usermonitor
+from landscape.client.amp import ComponentPublisher
+from landscape.client.manager.usermanager import UserManager
+from landscape.client.monitor.usermonitor import RemoteUserMonitorConnector
+from landscape.client.monitor.usermonitor import UserMonitor
+from landscape.client.tests.helpers import LandscapeTest
+from landscape.client.tests.helpers import MonitorHelper
+from landscape.client.user.tests.helpers import FakeUserProvider
 
 
 class UserMonitorNoManagerTest(LandscapeTest):
@@ -26,13 +28,26 @@ class UserMonitorNoManagerTest(LandscapeTest):
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
-                [{"create-group-members": {u"webdev": [u"jdoe"]},
-                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                  "create-users": [{"enabled": True, "home-phone": None,
-                                    "location": None, "name": u"JD",
-                                    "primary-gid": 1000, "uid": 1000,
-                                    "username": u"jdoe", "work-phone": None}],
-                  "type": "users"}])
+                [
+                    {
+                        "create-group-members": {"webdev": ["jdoe"]},
+                        "create-groups": [{"gid": 1000, "name": "webdev"}],
+                        "create-users": [
+                            {
+                                "enabled": True,
+                                "home-phone": None,
+                                "location": None,
+                                "name": "JD",
+                                "primary-gid": 1000,
+                                "uid": 1000,
+                                "username": "jdoe",
+                                "work-phone": None,
+                            },
+                        ],
+                        "type": "users",
+                    },
+                ],
+            )
             plugin.stop()
 
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh")]
@@ -51,28 +66,34 @@ class UserMonitorTest(LandscapeTest):
     helpers = [MonitorHelper]
 
     def setUp(self):
-        super(UserMonitorTest, self).setUp()
+        super().setUp()
         self.shadow_file = self.makeFile(
             "jdoe:$1$xFlQvTqe$cBtrNEDOIKMy/BuJoUdeG0:13348:0:99999:7:::\n"
             "psmith:!:13348:0:99999:7:::\n"
-            "sam:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::\n")
+            "sam:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::\n",
+        )
         self.user_manager = UserManager(shadow_file=self.shadow_file)
-        self.publisher = ComponentPublisher(self.user_manager, self.reactor,
-                                            self.config)
+        self.publisher = ComponentPublisher(
+            self.user_manager,
+            self.reactor,
+            self.config,
+        )
         self.publisher.start()
         self.provider = FakeUserProvider()
         self.plugin = UserMonitor(self.provider)
         # Part of bug 1048576 remediation:
         self._original_USER_UPDATE_FLAG_FILE = (
-            landscape.client.monitor.usermonitor.USER_UPDATE_FLAG_FILE)
+            landscape.client.monitor.usermonitor.USER_UPDATE_FLAG_FILE
+        )
 
     def tearDown(self):
         self.publisher.stop()
         self.plugin.stop()
         # Part of bug 1048576 remediation:
         landscape.client.monitor.usermonitor.USER_UPDATE_FLAG_FILE = (
-            self._original_USER_UPDATE_FLAG_FILE)
-        return super(UserMonitorTest, self).tearDown()
+            self._original_USER_UPDATE_FLAG_FILE
+        )
+        return super().tearDown()
 
     def test_constants(self):
         """
@@ -89,8 +110,9 @@ class UserMonitorTest(LandscapeTest):
         L{UserChange} snapshots should be cleared and a new message with users
         generated.
         """
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.broker_service.message_store.set_accepted_types(["users"])
         self.monitor.add(self.plugin)
@@ -99,36 +121,64 @@ class UserMonitorTest(LandscapeTest):
         self.assertTrue(persist.get("users"))
         self.assertTrue(persist.get("groups"))
         self.assertMessages(
-                self.broker_service.message_store.get_pending_messages(),
-                [{"create-group-members": {u"webdev": [u"jdoe"]},
-                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                  "create-users": [{"enabled": True, "home-phone": None,
-                                    "location": None, "name": u"JD",
-                                    "primary-gid": 1000, "uid": 1000,
-                                    "username": u"jdoe", "work-phone": None}],
-                  "type": "users"}])
+            self.broker_service.message_store.get_pending_messages(),
+            [
+                {
+                    "create-group-members": {"webdev": ["jdoe"]},
+                    "create-groups": [{"gid": 1000, "name": "webdev"}],
+                    "create-users": [
+                        {
+                            "enabled": True,
+                            "home-phone": None,
+                            "location": None,
+                            "name": "JD",
+                            "primary-gid": 1000,
+                            "uid": 1000,
+                            "username": "jdoe",
+                            "work-phone": None,
+                        },
+                    ],
+                    "type": "users",
+                },
+            ],
+        )
         self.broker_service.message_store.delete_all_messages()
         deferred = self.monitor.reactor.fire(
-            "resynchronize", scopes=["users"])[0]
+            "resynchronize",
+            scopes=["users"],
+        )[0]
         self.successResultOf(deferred)
         self.assertMessages(
             self.broker_service.message_store.get_pending_messages(),
-            [{"create-group-members": {u"webdev": [u"jdoe"]},
-              "create-groups": [{"gid": 1000, "name": u"webdev"}],
-              "create-users": [{"enabled": True, "home-phone": None,
-                                "location": None, "name": u"JD",
-                                "primary-gid": 1000, "uid": 1000,
-                                "username": u"jdoe",
-                                "work-phone": None}],
-              "type": "users"}])
+            [
+                {
+                    "create-group-members": {"webdev": ["jdoe"]},
+                    "create-groups": [{"gid": 1000, "name": "webdev"}],
+                    "create-users": [
+                        {
+                            "enabled": True,
+                            "home-phone": None,
+                            "location": None,
+                            "name": "JD",
+                            "primary-gid": 1000,
+                            "uid": 1000,
+                            "username": "jdoe",
+                            "work-phone": None,
+                        },
+                    ],
+                    "type": "users",
+                },
+            ],
+        )
 
     def test_new_message_after_resynchronize_event(self):
         """
         When a 'resynchronize' reactor event is fired, a new session is
         created and the UserMonitor creates a new message.
         """
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.broker_service.message_store.set_accepted_types(["users"])
         self.monitor.add(self.plugin)
@@ -137,21 +187,35 @@ class UserMonitorTest(LandscapeTest):
         self.successResultOf(deferred)
         self.assertMessages(
             self.broker_service.message_store.get_pending_messages(),
-            [{"create-group-members": {u"webdev": [u"jdoe"]},
-              "create-groups": [{"gid": 1000, "name": u"webdev"}],
-              "create-users": [{"enabled": True, "home-phone": None,
-                                "location": None, "name": u"JD",
-                                "primary-gid": 1000, "uid": 1000,
-                                "username": u"jdoe", "work-phone": None}],
-              "type": "users"}])
+            [
+                {
+                    "create-group-members": {"webdev": ["jdoe"]},
+                    "create-groups": [{"gid": 1000, "name": "webdev"}],
+                    "create-users": [
+                        {
+                            "enabled": True,
+                            "home-phone": None,
+                            "location": None,
+                            "name": "JD",
+                            "primary-gid": 1000,
+                            "uid": 1000,
+                            "username": "jdoe",
+                            "work-phone": None,
+                        },
+                    ],
+                    "type": "users",
+                },
+            ],
+        )
 
     def test_wb_resynchronize_event_with_global_scope(self):
         """
         When a C{resynchronize} event, with global scope, occurs we act exactly
         as if it had 'users' scope.
         """
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.broker_service.message_store.set_accepted_types(["users"])
         self.monitor.add(self.plugin)
@@ -160,35 +224,61 @@ class UserMonitorTest(LandscapeTest):
         self.assertTrue(persist.get("users"))
         self.assertTrue(persist.get("groups"))
         self.assertMessages(
-                self.broker_service.message_store.get_pending_messages(),
-                [{"create-group-members": {u"webdev": [u"jdoe"]},
-                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                  "create-users": [{"enabled": True, "home-phone": None,
-                                    "location": None, "name": u"JD",
-                                    "primary-gid": 1000, "uid": 1000,
-                                    "username": u"jdoe", "work-phone": None}],
-                  "type": "users"}])
+            self.broker_service.message_store.get_pending_messages(),
+            [
+                {
+                    "create-group-members": {"webdev": ["jdoe"]},
+                    "create-groups": [{"gid": 1000, "name": "webdev"}],
+                    "create-users": [
+                        {
+                            "enabled": True,
+                            "home-phone": None,
+                            "location": None,
+                            "name": "JD",
+                            "primary-gid": 1000,
+                            "uid": 1000,
+                            "username": "jdoe",
+                            "work-phone": None,
+                        },
+                    ],
+                    "type": "users",
+                },
+            ],
+        )
         self.broker_service.message_store.delete_all_messages()
         deferred = self.monitor.reactor.fire("resynchronize")[0]
         self.successResultOf(deferred)
         self.assertMessages(
             self.broker_service.message_store.get_pending_messages(),
-            [{"create-group-members": {u"webdev": [u"jdoe"]},
-              "create-groups": [{"gid": 1000, "name": u"webdev"}],
-              "create-users": [{"enabled": True, "home-phone": None,
-                                "location": None, "name": u"JD",
-                                "primary-gid": 1000, "uid": 1000,
-                                "username": u"jdoe",
-                                "work-phone": None}],
-              "type": "users"}])
+            [
+                {
+                    "create-group-members": {"webdev": ["jdoe"]},
+                    "create-groups": [{"gid": 1000, "name": "webdev"}],
+                    "create-users": [
+                        {
+                            "enabled": True,
+                            "home-phone": None,
+                            "location": None,
+                            "name": "JD",
+                            "primary-gid": 1000,
+                            "uid": 1000,
+                            "username": "jdoe",
+                            "work-phone": None,
+                        },
+                    ],
+                    "type": "users",
+                },
+            ],
+        )
 
     def test_do_not_resynchronize_with_other_scope(self):
         """
         When a C{resynchronize} event, with an irrelevant scope, occurs we do
         nothing.
         """
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.broker_service.message_store.set_accepted_types(["users"])
         self.monitor.add(self.plugin)
@@ -197,19 +287,33 @@ class UserMonitorTest(LandscapeTest):
         self.assertTrue(persist.get("users"))
         self.assertTrue(persist.get("groups"))
         self.assertMessages(
-                self.broker_service.message_store.get_pending_messages(),
-                [{"create-group-members": {u"webdev": [u"jdoe"]},
-                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                  "create-users": [{"enabled": True, "home-phone": None,
-                                    "location": None, "name": u"JD",
-                                    "primary-gid": 1000, "uid": 1000,
-                                    "username": u"jdoe", "work-phone": None}],
-                  "type": "users"}])
+            self.broker_service.message_store.get_pending_messages(),
+            [
+                {
+                    "create-group-members": {"webdev": ["jdoe"]},
+                    "create-groups": [{"gid": 1000, "name": "webdev"}],
+                    "create-users": [
+                        {
+                            "enabled": True,
+                            "home-phone": None,
+                            "location": None,
+                            "name": "JD",
+                            "primary-gid": 1000,
+                            "uid": 1000,
+                            "username": "jdoe",
+                            "work-phone": None,
+                        },
+                    ],
+                    "type": "users",
+                },
+            ],
+        )
         self.broker_service.message_store.delete_all_messages()
         self.monitor.reactor.fire("resynchronize", scopes=["disk"])[0]
         self.assertMessages(
             self.broker_service.message_store.get_pending_messages(),
-            [])
+            [],
+        )
 
     def test_run(self):
         """
@@ -221,16 +325,30 @@ class UserMonitorTest(LandscapeTest):
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
-                [{"create-group-members": {u"webdev": [u"jdoe"]},
-                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                  "create-users": [{"enabled": True, "home-phone": None,
-                                    "location": None, "name": u"JD",
-                                    "primary-gid": 1000, "uid": 1000,
-                                    "username": u"jdoe", "work-phone": None}],
-                  "type": "users"}])
+                [
+                    {
+                        "create-group-members": {"webdev": ["jdoe"]},
+                        "create-groups": [{"gid": 1000, "name": "webdev"}],
+                        "create-users": [
+                            {
+                                "enabled": True,
+                                "home-phone": None,
+                                "location": None,
+                                "name": "JD",
+                                "primary-gid": 1000,
+                                "uid": 1000,
+                                "username": "jdoe",
+                                "work-phone": None,
+                            },
+                        ],
+                        "type": "users",
+                    },
+                ],
+            )
 
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.broker_service.message_store.set_accepted_types(["users"])
         self.monitor.add(self.plugin)
@@ -262,17 +380,31 @@ class UserMonitorTest(LandscapeTest):
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
-                [{"create-group-members": {u"webdev": [u"jdoe"]},
-                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                  "create-users": [{"enabled": True, "home-phone": None,
-                                    "location": None, "name": u"JD",
-                                    "primary-gid": 1000, "uid": 1000,
-                                    "username": u"jdoe", "work-phone": None}],
-                  "operation-id": 1001,
-                  "type": "users"}])
+                [
+                    {
+                        "create-group-members": {"webdev": ["jdoe"]},
+                        "create-groups": [{"gid": 1000, "name": "webdev"}],
+                        "create-users": [
+                            {
+                                "enabled": True,
+                                "home-phone": None,
+                                "location": None,
+                                "name": "JD",
+                                "primary-gid": 1000,
+                                "uid": 1000,
+                                "username": "jdoe",
+                                "work-phone": None,
+                            },
+                        ],
+                        "operation-id": 1001,
+                        "type": "users",
+                    },
+                ],
+            )
 
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.monitor.add(self.plugin)
         self.broker_service.message_store.set_accepted_types(["users"])
@@ -281,21 +413,34 @@ class UserMonitorTest(LandscapeTest):
         return result
 
     def test_detect_changes(self):
-
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
-                [{"create-group-members": {u"webdev": [u"jdoe"]},
-                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                  "create-users": [{"enabled": True, "home-phone": None,
-                                    "location": None, "name": u"JD",
-                                    "primary-gid": 1000, "uid": 1000,
-                                    "username": u"jdoe", "work-phone": None}],
-                  "type": "users"}])
+                [
+                    {
+                        "create-group-members": {"webdev": ["jdoe"]},
+                        "create-groups": [{"gid": 1000, "name": "webdev"}],
+                        "create-users": [
+                            {
+                                "enabled": True,
+                                "home-phone": None,
+                                "location": None,
+                                "name": "JD",
+                                "primary-gid": 1000,
+                                "uid": 1000,
+                                "username": "jdoe",
+                                "work-phone": None,
+                            },
+                        ],
+                        "type": "users",
+                    },
+                ],
+            )
 
         self.broker_service.message_store.set_accepted_types(["users"])
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
 
         self.monitor.add(self.plugin)
@@ -315,18 +460,32 @@ class UserMonitorTest(LandscapeTest):
         def got_result(result):
             self.assertMessages(
                 self.broker_service.message_store.get_pending_messages(),
-                [{"create-group-members": {u"webdev": [u"jdoe"]},
-                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                  "create-users": [{"enabled": True, "home-phone": None,
-                                    "location": None, "name": u"JD",
-                                    "primary-gid": 1000, "uid": 1000,
-                                    "username": u"jdoe", "work-phone": None}],
-                  "operation-id": 1001,
-                  "type": "users"}])
+                [
+                    {
+                        "create-group-members": {"webdev": ["jdoe"]},
+                        "create-groups": [{"gid": 1000, "name": "webdev"}],
+                        "create-users": [
+                            {
+                                "enabled": True,
+                                "home-phone": None,
+                                "location": None,
+                                "name": "JD",
+                                "primary-gid": 1000,
+                                "uid": 1000,
+                                "username": "jdoe",
+                                "work-phone": None,
+                            },
+                        ],
+                        "operation-id": 1001,
+                        "type": "users",
+                    },
+                ],
+            )
 
         self.broker_service.message_store.set_accepted_types(["users"])
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.monitor.add(self.plugin)
         connector = RemoteUserMonitorConnector(self.reactor, self.config)
@@ -344,7 +503,7 @@ class UserMonitorTest(LandscapeTest):
         """
         self.monitor.add(self.plugin)
 
-        class FauxUserChanges(object):
+        class FauxUserChanges:
             cleared = False
 
             def __init__(self, *args):
@@ -357,13 +516,14 @@ class UserMonitorTest(LandscapeTest):
                 self.__class__.cleared = True
 
         # Create the (temporary, test) user update flag file.
-        landscape.client.monitor.usermonitor.USER_UPDATE_FLAG_FILE = \
-            update_flag_file = self.makeFile("")
+        landscape.client.monitor.usermonitor.USER_UPDATE_FLAG_FILE = (
+            update_flag_file
+        ) = self.makeFile("")
         self.addCleanup(lambda: os.remove(update_flag_file))
 
         # Trigger a detect changes.
         self.plugin._persist = None
-        self.plugin._detect_changes([], UserChanges=FauxUserChanges)
+        self.plugin._detect_changes([], userchanges=FauxUserChanges)
 
         # The clear() method was called.
         self.assertTrue(FauxUserChanges.cleared)
@@ -379,12 +539,14 @@ class UserMonitorTest(LandscapeTest):
             self.assertFalse(os.path.exists(update_flag_file))
 
         # Create the (temporary, test) user update flag file.
-        landscape.client.monitor.usermonitor.USER_UPDATE_FLAG_FILE = \
-            update_flag_file = self.makeFile("")
+        landscape.client.monitor.usermonitor.USER_UPDATE_FLAG_FILE = (
+            update_flag_file
+        ) = self.makeFile("")
 
         self.broker_service.message_store.set_accepted_types(["users"])
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = []
 
         self.monitor.add(self.plugin)
@@ -408,8 +570,9 @@ class UserMonitorTest(LandscapeTest):
             self.assertMessages(list(mstore.get_pending_messages()), [])
 
         self.broker_service.message_store.set_accepted_types([])
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.monitor.add(self.plugin)
         connector = RemoteUserMonitorConnector(self.reactor, self.config)
@@ -420,27 +583,42 @@ class UserMonitorTest(LandscapeTest):
         return result
 
     def test_call_on_accepted(self):
-
         def got_result(result):
             mstore = self.broker_service.message_store
             self.assertMessages(
                 mstore.get_pending_messages(),
-                [{"create-group-members": {u"webdev": [u"jdoe"]},
-                  "create-groups": [{"gid": 1000, "name": u"webdev"}],
-                  "create-users": [{"enabled": True, "home-phone": None,
-                                    "location": None, "name": u"JD",
-                                    "primary-gid": 1000, "uid": 1000,
-                                    "username": u"jdoe", "work-phone": None}],
-                  "type": "users"}])
+                [
+                    {
+                        "create-group-members": {"webdev": ["jdoe"]},
+                        "create-groups": [{"gid": 1000, "name": "webdev"}],
+                        "create-users": [
+                            {
+                                "enabled": True,
+                                "home-phone": None,
+                                "location": None,
+                                "name": "JD",
+                                "primary-gid": 1000,
+                                "uid": 1000,
+                                "username": "jdoe",
+                                "work-phone": None,
+                            },
+                        ],
+                        "type": "users",
+                    },
+                ],
+            )
 
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.monitor.add(self.plugin)
 
         self.broker_service.message_store.set_accepted_types(["users"])
         result = self.reactor.fire(
-            ("message-type-acceptance-changed", "users"), True)
+            ("message-type-acceptance-changed", "users"),
+            True,
+        )
         result = [x for x in result if x][0]
         result.addCallback(got_result)
         return result
@@ -463,11 +641,13 @@ class UserMonitorTest(LandscapeTest):
 
         self.broker_service.message_store.set_accepted_types(["users"])
 
-        self.monitor.broker.send_message = Mock(return_value=fail(
-            RuntimeError()))
+        self.monitor.broker.send_message = Mock(
+            return_value=fail(RuntimeError()),
+        )
 
-        self.provider.users = [("jdoe", "x", 1000, 1000, "JD,,,,",
-                                "/home/jdoe", "/bin/sh")]
+        self.provider.users = [
+            ("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/sh"),
+        ]
         self.provider.groups = [("webdev", "x", 1000, ["jdoe"])]
         self.monitor.add(self.plugin)
         connector = RemoteUserMonitorConnector(self.reactor, self.config)
@@ -476,4 +656,7 @@ class UserMonitorTest(LandscapeTest):
         result.addCallback(got_result)
         result.addCallback(lambda x: connector.disconnect())
         self.monitor.broker.send_message.assert_called_once_with(
-            ANY, ANY, urgent=True)
+            ANY,
+            ANY,
+            urgent=True,
+        )
