@@ -1,34 +1,51 @@
-from landscape.lib.testing import MockPopen
-from landscape.client.user.management import (
-        UserManagement, UserManagementError)
-from landscape.client.user.tests.helpers import FakeUserProvider
-from landscape.client.user.provider import (
-        UserNotFoundError, GroupNotFoundError)
 from landscape.client.tests.helpers import LandscapeTest
+from landscape.client.user.management import UserManagement
+from landscape.client.user.management import UserManagementError
+from landscape.client.user.provider import GroupNotFoundError
+from landscape.client.user.provider import UserNotFoundError
+from landscape.client.user.tests.helpers import FakeUserProvider
+from landscape.lib.testing import MockPopen
 
 
 class UserWriteTest(LandscapeTest):
-
     def setUp(self):
         LandscapeTest.setUp(self)
-        self.shadow_file = self.makeFile("""\
+        self.shadow_file = self.makeFile(
+            """\
 jdoe:$1$xFlQvTqe$cBtrNEDOIKMy/BuJoUdeG0:13348:0:99999:7:::
 psmith:!:13348:0:99999:7:::
 sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
-""")
+""",
+        )
 
     def test_add_user(self):
         """L{UserManagement.add_user} should use C{adduser} to add users."""
         groups = [("users", "x", 1001, [])]
         provider = FakeUserProvider(groups=groups, popen=MockPopen(""))
         management = UserManagement(provider=provider)
-        management.add_user("jdoe", "John Doe", "password", False, "users",
-                            "Room 101", "+123456", None)
+        management.add_user(
+            "jdoe",
+            "John Doe",
+            "password",
+            False,
+            "users",
+            "Room 101",
+            "+123456",
+            None,
+        )
         self.assertEqual(len(provider.popen.popen_inputs), 2)
-        self.assertEqual(provider.popen.popen_inputs[0],
-                         ["adduser", "jdoe", "--disabled-password",
-                          "--gecos", "John Doe,Room 101,+123456,",
-                          "--gid", "1001"])
+        self.assertEqual(
+            provider.popen.popen_inputs[0],
+            [
+                "adduser",
+                "jdoe",
+                "--disabled-password",
+                "--gecos",
+                "John Doe,Room 101,+123456,",
+                "--gid",
+                "1001",
+            ],
+        )
 
         chpasswd = provider.popen.popen_inputs[1]
         self.assertEqual(len(chpasswd), 1, chpasswd)
@@ -41,9 +58,18 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         provider = FakeUserProvider(popen=MockPopen("", return_codes=[1, 0]))
         management = UserManagement(provider=provider)
-        self.assertRaises(UserManagementError, management.add_user,
-                          "jdoe", u"John Doe", "password", False, None, None,
-                          None, None)
+        self.assertRaises(
+            UserManagementError,
+            management.add_user,
+            "jdoe",
+            "John Doe",
+            "password",
+            False,
+            None,
+            None,
+            None,
+            None,
+        )
 
     def test_change_password_error(self):
         """
@@ -54,10 +80,20 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         provider.popen.err_out = b"PAM is unhappy"
         management = UserManagement(provider=provider)
         with self.assertRaises(UserManagementError) as e:
-            management.add_user("jdoe", u"John Doe", "password", False, None,
-                                None, None, None)
+            management.add_user(
+                "jdoe",
+                "John Doe",
+                "password",
+                False,
+                None,
+                None,
+                None,
+                None,
+            )
         expected = "Error setting password for user {}.\n {}".format(
-            b"jdoe", b"PAM is unhappy")
+            b"jdoe",
+            b"PAM is unhappy",
+        )
         self.assertEqual(expected, str(e.exception))
 
     def test_expire_password_error(self):
@@ -66,11 +102,21 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         C{passwd} fails.
         """
         provider = FakeUserProvider(
-            popen=MockPopen("", return_codes=[0, 0, 1]))
+            popen=MockPopen("", return_codes=[0, 0, 1]),
+        )
         management = UserManagement(provider=provider)
-        self.assertRaises(UserManagementError, management.add_user,
-                          "jdoe", u"John Doe", "password", True, None, None,
-                          None, None)
+        self.assertRaises(
+            UserManagementError,
+            management.add_user,
+            "jdoe",
+            "John Doe",
+            "password",
+            True,
+            None,
+            None,
+            None,
+            None,
+        )
 
     def test_set_password(self):
         """
@@ -78,8 +124,11 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         a user's password.
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
         management.set_user_details("jdoe", password="password")
 
@@ -92,9 +141,11 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         users.
         """
         data = [("root", "x", 0, 0, ",,,,", "/home/root", "/bin/zsh")]
-        provider = FakeUserProvider(users=data,
-                                    shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
         management.set_user_details("root", password="password")
         self.assertEqual(len(provider.popen.popen_inputs), 1)
@@ -107,10 +158,13 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         non-ASCII-encodable still probably won't work).
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
-        management.set_user_details("jdoe", password=u"password")
+        management.set_user_details("jdoe", password="password")
 
         self.assertEqual(len(provider.popen.popen_inputs), 1)
         self.assertEqual(b"jdoe:password", provider.popen.received_input)
@@ -121,14 +175,19 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         change a user's name.
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
         management.set_user_details("jdoe", name="JD")
 
         self.assertEqual(len(provider.popen.popen_inputs), 1)
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["chfn", "-f", "JD", "jdoe"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["chfn", "-f", "JD", "jdoe"]],
+        )
 
     def test_set_location(self):
         """
@@ -136,44 +195,77 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         change a user's location.
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
         management.set_user_details("jdoe", location="Everywhere")
 
         self.assertEqual(len(provider.popen.popen_inputs), 1)
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["chfn", "-r", "Everywhere", "jdoe"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["chfn", "-r", "Everywhere", "jdoe"]],
+        )
 
     def test_clear_user_location(self):
         """
         L{UserManagement.set_user_details} should use C{chfn} to
         change a user's location.
         """
-        data = [("jdoe", "x", 1000, 1000, "JD,Room 101,,,", "/home/jdoe",
-                 "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        data = [
+            (
+                "jdoe",
+                "x",
+                1000,
+                1000,
+                "JD,Room 101,,,",
+                "/home/jdoe",
+                "/bin/zsh",
+            ),
+        ]
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
         management.set_user_details("jdoe", location="")
         self.assertEqual(len(provider.popen.popen_inputs), 1)
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["chfn", "-r", "", "jdoe"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["chfn", "-r", "", "jdoe"]],
+        )
 
     def test_clear_telephone_numbers(self):
         """
         L{UserManagement.set_user_details} should use C{chfn} to
         change a user's telephone numbers.
         """
-        data = [("jdoe", "x", 1000, 1000, "JD,,+123456,+123456", "/home/jdoe",
-                 "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        data = [
+            (
+                "jdoe",
+                "x",
+                1000,
+                1000,
+                "JD,,+123456,+123456",
+                "/home/jdoe",
+                "/bin/zsh",
+            ),
+        ]
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
         management.set_user_details("jdoe", home_number="", work_number="")
         self.assertEqual(len(provider.popen.popen_inputs), 1)
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["chfn", "-w", "", "-h", "", "jdoe"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["chfn", "-w", "", "-h", "", "jdoe"]],
+        )
 
     def test_set_user_details_fails(self):
         """
@@ -181,11 +273,18 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         L{EditUserError} if C{chfn} fails.
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("", return_codes=[1]))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("", return_codes=[1]),
+        )
         management = UserManagement(provider=provider)
-        self.assertRaises(UserNotFoundError, management.set_user_details, 1000,
-                          name="John Doe")
+        self.assertRaises(
+            UserNotFoundError,
+            management.set_user_details,
+            1000,
+            name="John Doe",
+        )
 
     def test_contact_details_in_general(self):
         """
@@ -193,20 +292,38 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         change a user's contact details.
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
-        location = u"Everywhere"
-        work_number = u"1-800-123-4567"
-        home_number = u"764-4321"
-        management.set_user_details("jdoe", location=location,
-                                    work_number=work_number,
-                                    home_number=home_number)
+        location = "Everywhere"
+        work_number = "1-800-123-4567"
+        home_number = "764-4321"
+        management.set_user_details(
+            "jdoe",
+            location=location,
+            work_number=work_number,
+            home_number=home_number,
+        )
 
         self.assertEqual(len(provider.popen.popen_inputs), 1)
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["chfn", "-r", location, "-w", work_number,
-                           "-h", home_number, "jdoe"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [
+                [
+                    "chfn",
+                    "-r",
+                    location,
+                    "-w",
+                    work_number,
+                    "-h",
+                    home_number,
+                    "jdoe",
+                ],
+            ],
+        )
 
     def test_set_user_details_with_unknown_username(self):
         """
@@ -215,8 +332,12 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         provider = FakeUserProvider(popen=MockPopen(""))
         management = UserManagement(provider=provider)
-        self.assertRaises(UserNotFoundError, management.set_user_details,
-                          "kevin", name=u"John Doe")
+        self.assertRaises(
+            UserNotFoundError,
+            management.set_user_details,
+            "kevin",
+            name="John Doe",
+        )
 
     def test_set_primary_group(self):
         """
@@ -225,15 +346,20 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("users", "x", 1001, [])]
-        provider = FakeUserProvider(users=data, groups=groups,
-                                    shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        provider = FakeUserProvider(
+            users=data,
+            groups=groups,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
 
         management = UserManagement(provider=provider)
         management.set_user_details("jdoe", primary_group_name="users")
 
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["usermod", "-g", "1001", "jdoe"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["usermod", "-g", "1001", "jdoe"]],
+        )
 
     def test_set_primary_group_unknown_group(self):
         """
@@ -243,24 +369,34 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("staff", "x", 1001, [])]
-        provider = FakeUserProvider(users=data, groups=groups,
-                                    shadow_file=self.shadow_file,
-                                    popen=MockPopen("group id 1002 unknown",
-                                                    return_codes=[1]),
-                                    )
+        provider = FakeUserProvider(
+            users=data,
+            groups=groups,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("group id 1002 unknown", return_codes=[1]),
+        )
         management = UserManagement(provider=provider)
-        self.assertRaises(GroupNotFoundError, management.set_user_details,
-                          "jdoe", primary_group_name="unknown")
+        self.assertRaises(
+            GroupNotFoundError,
+            management.set_user_details,
+            "jdoe",
+            primary_group_name="unknown",
+        )
 
     def test_lock_user(self):
         """L{UserManagement.lock_user} should use C{usermod} to lock users."""
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
         management.lock_user("jdoe")
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["usermod", "-L", "jdoe"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["usermod", "-L", "jdoe"]],
+        )
 
     def test_lock_user_fails(self):
         """
@@ -268,8 +404,11 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         a C{usermod} fails.
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("", [1]))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("", [1]),
+        )
         management = UserManagement(provider=provider)
         self.assertRaises(UserNotFoundError, management.lock_user, 1000)
 
@@ -288,12 +427,17 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         users.
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("no output"))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
         management.unlock_user("jdoe")
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["usermod", "-U", "jdoe"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["usermod", "-U", "jdoe"]],
+        )
 
     def test_unlock_user_fails(self):
         """
@@ -301,8 +445,11 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         L{UserManagementError} if a C{usermod} fails.
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=MockPopen("", [1]))
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("", [1]),
+        )
         management = UserManagement(provider=provider)
         self.assertRaises(UserNotFoundError, management.unlock_user, 1000)
 
@@ -322,8 +469,11 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         popen = MockPopen("Removing user `jdoe'...\r\ndone.")
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=popen)
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=popen,
+        )
         management = UserManagement(provider=provider)
         management.remove_user("jdoe")
         self.assertEqual(popen.popen_inputs, [["deluser", "jdoe"]])
@@ -344,10 +494,16 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         self.log_helper.ignore_errors(UserNotFoundError)
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        popen = MockPopen("/usr/sbin/deluser: Only root may remove a user or "
-                          "group from the system.", [1])
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=popen)
+        popen = MockPopen(
+            "/usr/sbin/deluser: Only root may remove a user or "
+            "group from the system.",
+            [1],
+        )
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=popen,
+        )
         management = UserManagement(provider=provider)
         self.assertRaises(UserNotFoundError, management.remove_user, "smith")
 
@@ -358,23 +514,29 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         data = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         popen = MockPopen("Removing user `jdoe`...\r\ndone.", [0])
-        provider = FakeUserProvider(users=data, shadow_file=self.shadow_file,
-                                    popen=popen)
+        provider = FakeUserProvider(
+            users=data,
+            shadow_file=self.shadow_file,
+            popen=popen,
+        )
         management = UserManagement(provider=provider)
         management.remove_user("jdoe", delete_home=True)
-        self.assertEqual(popen.popen_inputs,
-                         [["deluser", "jdoe", "--remove-home"]])
+        self.assertEqual(
+            popen.popen_inputs,
+            [["deluser", "jdoe", "--remove-home"]],
+        )
 
 
 class GroupWriteTest(LandscapeTest):
-
     def setUp(self):
         LandscapeTest.setUp(self)
-        self.shadow_file = self.makeFile("""\
+        self.shadow_file = self.makeFile(
+            """\
 jdoe:$1$xFlQvTqe$cBtrNEDOIKMy/BuJoUdeG0:13348:0:99999:7:::
 psmith:!:13348:0:99999:7:::
 sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
-""")
+""",
+        )
 
     def test_add_group(self):
         """
@@ -384,8 +546,7 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         provider = FakeUserProvider(popen=MockPopen("Result"))
         management = UserManagement(provider=provider)
         result = management.add_group("webdev")
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["addgroup", "webdev"]])
+        self.assertEqual(provider.popen.popen_inputs, [["addgroup", "webdev"]])
         self.assertEqual(result, "Result")
 
     def test_add_group_handles_errors(self):
@@ -405,13 +566,18 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("bizdev", "x", 1001, [])]
         provider = FakeUserProvider(
-            users=users, shadow_file=self.shadow_file,
-            groups=groups, popen=MockPopen("no output"))
+            users=users,
+            shadow_file=self.shadow_file,
+            groups=groups,
+            popen=MockPopen("no output"),
+        )
         management = UserManagement(provider=provider)
         management.set_group_details("bizdev", "sales")
 
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["groupmod", "-n", "sales", "bizdev"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["groupmod", "-n", "sales", "bizdev"]],
+        )
 
     def test_set_group_details_with_unknown_groupname(self):
         """
@@ -420,8 +586,12 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         provider = FakeUserProvider(popen=MockPopen(""))
         management = UserManagement(provider=provider)
-        self.assertRaises(GroupNotFoundError, management.set_group_details,
-                          "sales", u"newsales")
+        self.assertRaises(
+            GroupNotFoundError,
+            management.set_group_details,
+            "sales",
+            "newsales",
+        )
 
     def test_set_group_details_fails(self):
         """
@@ -431,11 +601,19 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("bizdev", "x", 1001, [])]
         popen = MockPopen("groupmod: sales is not a unique name", [1])
-        provider = FakeUserProvider(users=users, shadow_file=self.shadow_file,
-                                    groups=groups, popen=popen)
+        provider = FakeUserProvider(
+            users=users,
+            shadow_file=self.shadow_file,
+            groups=groups,
+            popen=popen,
+        )
         management = UserManagement(provider=provider)
-        self.assertRaises(UserManagementError, management.set_group_details,
-                          "bizdev", u"sales")
+        self.assertRaises(
+            UserManagementError,
+            management.set_group_details,
+            "bizdev",
+            "sales",
+        )
 
     def test_add_member(self):
         """
@@ -444,16 +622,19 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("bizdev", "x", 1001, [])]
-        provider = FakeUserProvider(users=users, shadow_file=self.shadow_file,
-                                    groups=groups,
-                                    popen=MockPopen("Removing user jdoe "
-                                                    "from group bizdev"),
-                                    )
+        provider = FakeUserProvider(
+            users=users,
+            shadow_file=self.shadow_file,
+            groups=groups,
+            popen=MockPopen("Removing user jdoe " "from group bizdev"),
+        )
         management = UserManagement(provider=provider)
 
         output = management.add_group_member("jdoe", "bizdev")
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["gpasswd", "-a", "jdoe", "bizdev"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["gpasswd", "-a", "jdoe", "bizdev"]],
+        )
         self.assertEqual(output, "Removing user jdoe from group bizdev")
 
     def test_add_member_with_unknown_groupname(self):
@@ -463,11 +644,18 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         exist.
         """
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=users, shadow_file=self.shadow_file,
-                                    popen=MockPopen(""))
+        provider = FakeUserProvider(
+            users=users,
+            shadow_file=self.shadow_file,
+            popen=MockPopen(""),
+        )
         management = UserManagement(provider=provider)
-        self.assertRaises(GroupNotFoundError, management.add_group_member,
-                          "jdoe", "bizdev")
+        self.assertRaises(
+            GroupNotFoundError,
+            management.add_group_member,
+            "jdoe",
+            "bizdev",
+        )
 
     def test_add_member_with_unknown_username(self):
         """
@@ -478,8 +666,12 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         groups = [("bizdev", "x", 1001, [])]
         provider = FakeUserProvider(groups=groups, popen=MockPopen(""))
         management = UserManagement(provider=provider)
-        self.assertRaises(UserNotFoundError, management.add_group_member,
-                          "bizdev", "smith")
+        self.assertRaises(
+            UserNotFoundError,
+            management.add_group_member,
+            "bizdev",
+            "smith",
+        )
 
     def test_add_member_failure(self):
         """
@@ -489,12 +681,19 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("bizdev", "x", 1001, [])]
-        provider = FakeUserProvider(users=users, shadow_file=self.shadow_file,
-                                    groups=groups,
-                                    popen=MockPopen("no output", [1]))
+        provider = FakeUserProvider(
+            users=users,
+            shadow_file=self.shadow_file,
+            groups=groups,
+            popen=MockPopen("no output", [1]),
+        )
         management = UserManagement(provider=provider)
-        self.assertRaises(UserNotFoundError, management.add_group_member,
-                          1000, 1001)
+        self.assertRaises(
+            UserNotFoundError,
+            management.add_group_member,
+            1000,
+            1001,
+        )
 
     def test_remove_member(self):
         """
@@ -504,15 +703,18 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("bizdev", "x", 1001, [])]
-        provider = FakeUserProvider(users=users, shadow_file=self.shadow_file,
-                                    groups=groups,
-                                    popen=MockPopen("Removing user jdoe "
-                                                    "from group bizdev"),
-                                    )
+        provider = FakeUserProvider(
+            users=users,
+            shadow_file=self.shadow_file,
+            groups=groups,
+            popen=MockPopen("Removing user jdoe " "from group bizdev"),
+        )
         management = UserManagement(provider=provider)
         output = management.remove_group_member("jdoe", "bizdev")
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["gpasswd", "-d", "jdoe", "bizdev"]])
+        self.assertEqual(
+            provider.popen.popen_inputs,
+            [["gpasswd", "-d", "jdoe", "bizdev"]],
+        )
         self.assertEqual(output, "Removing user jdoe from group bizdev")
 
     def test_remove_member_with_unknown_groupname(self):
@@ -522,11 +724,18 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         doesn't exist.
         """
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
-        provider = FakeUserProvider(users=users, shadow_file=self.shadow_file,
-                                    popen=MockPopen("", return_codes=[2]))
+        provider = FakeUserProvider(
+            users=users,
+            shadow_file=self.shadow_file,
+            popen=MockPopen("", return_codes=[2]),
+        )
         management = UserManagement(provider=provider)
-        self.assertRaises(GroupNotFoundError, management.remove_group_member,
-                          "jdoe", "bizdev")
+        self.assertRaises(
+            GroupNotFoundError,
+            management.remove_group_member,
+            "jdoe",
+            "bizdev",
+        )
 
     def test_remove_member_with_unknown_username(self):
         """
@@ -535,11 +744,17 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         exist.
         """
         groups = [("bizdev", "x", 1001, [])]
-        provider = FakeUserProvider(groups=groups,
-                                    popen=MockPopen("", return_codes=[4]))
+        provider = FakeUserProvider(
+            groups=groups,
+            popen=MockPopen("", return_codes=[4]),
+        )
         management = UserManagement(provider=provider)
-        self.assertRaises(UserNotFoundError, management.remove_group_member,
-                          "jdoe", "bizdev")
+        self.assertRaises(
+            UserNotFoundError,
+            management.remove_group_member,
+            "jdoe",
+            "bizdev",
+        )
 
     def test_remove_member_failure(self):
         """
@@ -549,12 +764,19 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("bizdev", "x", 1001, [])]
-        provider = FakeUserProvider(users=users, shadow_file=self.shadow_file,
-                                    groups=groups,
-                                    popen=MockPopen("no output", [1]))
+        provider = FakeUserProvider(
+            users=users,
+            shadow_file=self.shadow_file,
+            groups=groups,
+            popen=MockPopen("no output", [1]),
+        )
         management = UserManagement(provider=provider)
-        self.assertRaises(UserManagementError,
-                          management.remove_group_member, "jdoe", "bizdev")
+        self.assertRaises(
+            UserManagementError,
+            management.remove_group_member,
+            "jdoe",
+            "bizdev",
+        )
 
     def test_remove_group(self):
         """
@@ -564,12 +786,15 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("bizdev", "x", 50, [])]
         popen = MockPopen("Removing group `bizdev'...\r\ndone.")
-        provider = FakeUserProvider(users=users, shadow_file=self.shadow_file,
-                                    groups=groups, popen=popen)
+        provider = FakeUserProvider(
+            users=users,
+            shadow_file=self.shadow_file,
+            groups=groups,
+            popen=popen,
+        )
         management = UserManagement(provider=provider)
         management.remove_group("bizdev")
-        self.assertEqual(provider.popen.popen_inputs,
-                         [["groupdel", "bizdev"]])
+        self.assertEqual(provider.popen.popen_inputs, [["groupdel", "bizdev"]])
 
     def test_remove_group_with_unknown_groupname(self):
         """
@@ -579,7 +804,10 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         provider = FakeUserProvider(popen=MockPopen(""))
         management = UserManagement(provider=provider)
         self.assertRaises(
-            GroupNotFoundError, management.remove_group, "ubuntu")
+            GroupNotFoundError,
+            management.remove_group,
+            "ubuntu",
+        )
 
     def test_remove_group_fails(self):
         """
@@ -588,10 +816,20 @@ sbarnes:$1$q7sz09uw$q.A3526M/SHu8vUb.Jo1A/:13349:0:99999:7:::
         """
         users = [("jdoe", "x", 1000, 1000, "JD,,,,", "/home/jdoe", "/bin/zsh")]
         groups = [("bizdev", "x", 50, [])]
-        popen = MockPopen("/usr/sbin/deluser: Only root may remove a user or "
-                          "group from the system.", [1])
-        provider = FakeUserProvider(users=users, shadow_file=self.shadow_file,
-                                    groups=groups, popen=popen)
+        popen = MockPopen(
+            "/usr/sbin/deluser: Only root may remove a user or "
+            "group from the system.",
+            [1],
+        )
+        provider = FakeUserProvider(
+            users=users,
+            shadow_file=self.shadow_file,
+            groups=groups,
+            popen=popen,
+        )
         management = UserManagement(provider=provider)
         self.assertRaises(
-            GroupNotFoundError, management.remove_group, "ubuntu")
+            GroupNotFoundError,
+            management.remove_group,
+            "ubuntu",
+        )
